-- 用户表
CREATE TABLE users (
    user_id INT AUTO_INCREMENT PRIMARY KEY,
    -- 用户ID
    username VARCHAR(50) NOT NULL UNIQUE,
    -- 用户名
    password_hash VARCHAR(255) NOT NULL,
    -- 用户密码（哈希值）
    full_name VARCHAR(100) NOT NULL,
    -- 用户姓名
    phone VARCHAR(20) NOT NULL,
    -- 用户电话
    user_address VARCHAR(255) DEFAULT NULL,
    -- 用户地址（允许为空）
    user_role VARCHAR(50) NOT NULL,
    -- 用户角色（支持中文）
    created_at TIMESTAMP DEFAULT CURRENT_TIMESTAMP,
    -- 创建时间
    updated_at TIMESTAMP DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP -- 最后更新时间
);

-- 插入初始管理员用户
INSERT INTO
    users (
        username,
        password_hash,
        full_name,
        phone,
        user_address,
        user_role
    )
VALUES
    (
        'admin',
        SHA2('admin', 256),
        '管理员',
        '13888888888',
        NULL,
        '管理员'
    );

-- 操作日志表
CREATE TABLE operation_logs (
    log_id INT AUTO_INCREMENT PRIMARY KEY COMMENT '日志ID，主键',
    -- 日志ID
    user_id INT NOT NULL COMMENT '操作用户ID',
    -- 操作用户ID
    operation_type VARCHAR(50) NOT NULL COMMENT '操作类型',
    -- 操作类型（如登录、删除、更新等）
    operation_details TEXT COMMENT '操作详情',
    -- 操作详情（记录具体操作内容）
    operation_time TIMESTAMP DEFAULT CURRENT_TIMESTAMP COMMENT '操作时间',
    -- 操作时间
    FOREIGN KEY (user_id) REFERENCES users(user_id) -- 外键，关联用户表
) COMMENT = '操作日志表';

-- 假设用户ID为1的用户执行了登录操作
INSERT INTO
    operation_logs (user_id, operation_type, operation_details)
VALUES
    (1, '登录', '用户 admin 登录系统');

-- 假设用户ID为1的用户执行了删除操作
INSERT INTO
    operation_logs (user_id, operation_type, operation_details)
VALUES
    (
        1,
        '删除',
        '用户 admin 删除了ID为2的用户'
    );

-- 数据备份表
CREATE TABLE data_backups (
    backup_id INT AUTO_INCREMENT PRIMARY KEY COMMENT '备份ID，主键',
    -- 备份ID
    backup_name VARCHAR(100) NOT NULL COMMENT '备份名称',
    -- 备份名称
    backup_path VARCHAR(255) NOT NULL COMMENT '备份文件路径',
    -- 备份文件路径
    backup_time TIMESTAMP DEFAULT CURRENT_TIMESTAMP COMMENT '备份时间',
    -- 备份时间
    status ENUM('success', 'failed') DEFAULT 'success' COMMENT '备份状态' -- 备份状态（成功或失败）
) COMMENT = '数据备份表';

-- 供应商表
CREATE TABLE suppliers (
    supplier_id INT AUTO_INCREMENT PRIMARY KEY COMMENT '供应商ID，主键',
    -- 供应商ID
    supplier_name VARCHAR(100) NOT NULL COMMENT '供应商名称',
    -- 供应商名称
    contact_name VARCHAR(50) COMMENT '联系人姓名',
    -- 联系人姓名
    contact_phone VARCHAR(20) COMMENT '联系人电话',
    -- 联系人电话
    address VARCHAR(255) COMMENT '供应商地址',
    -- 供应商地址
    total_payable DECIMAL(15, 2) DEFAULT 0.00 COMMENT '应付账款总额',
    -- 应付账款总额
    total_paid DECIMAL(15, 2) DEFAULT 0.00 COMMENT '已付款总额',
    -- 已付款总额
    created_at TIMESTAMP DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
    -- 创建时间
    updated_at TIMESTAMP DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT '最后更新时间' -- 最后更新时间
) COMMENT = '供应商表';

INSERT INTO
    suppliers (
        supplier_name,
        contact_name,
        contact_phone,
        address
    )
VALUES
    ('供应商A', '张三', '13800138000', '北京市朝阳区'),
    ('供应商B', '李四', '13900139000', '上海市浦东新区');

-- 采购订单表
CREATE TABLE purchase_orders (
    order_id INT AUTO_INCREMENT PRIMARY KEY COMMENT '采购订单ID，主键',
    -- 采购订单ID
    supplier_id INT NOT NULL COMMENT '供应商ID',
    -- 供应商ID
    order_number VARCHAR(50) NOT NULL COMMENT '采购订单编号',
    -- 采购订单编号
    order_date DATE NOT NULL COMMENT '订单日期',
    -- 订单日期
    total_amount DECIMAL(15, 2) NOT NULL COMMENT '订单总金额',
    -- 订单总金额
    status ENUM('pending', 'approved', 'rejected') DEFAULT 'pending' COMMENT '订单状态',
    -- 订单状态
    created_at TIMESTAMP DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
    -- 创建时间
    updated_at TIMESTAMP DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT '最后更新时间',
    -- 最后更新时间
    FOREIGN KEY (supplier_id) REFERENCES suppliers(supplier_id) -- 外键，关联供应商表
) COMMENT = '采购订单表';

INSERT INTO
    purchase_orders (
        supplier_id,
        order_number,
        order_date,
        total_amount,
        status
    )
VALUES
    (
        1,
        'PO20231001',
        '2023-10-01',
        5000.00,
        'approved'
    ),
    (
        2,
        'PO20231002',
        '2023-10-02',
        3000.00,
        'pending'
    );

-- 采购入库表
CREATE TABLE purchase_stock (
    stock_id INT AUTO_INCREMENT PRIMARY KEY COMMENT '入库ID，主键',
    -- 入库ID
    order_id INT NOT NULL COMMENT '采购订单ID',
    -- 采购订单ID
    batch_number VARCHAR(50) NOT NULL COMMENT '批次号',
    -- 批次号
    inspection_status ENUM('pending', 'passed', 'failed') DEFAULT 'pending' COMMENT '质检状态',
    -- 质检状态
    loss_amount DECIMAL(15, 2) DEFAULT 0.00 COMMENT '损耗金额',
    -- 损耗金额
    created_at TIMESTAMP DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
    -- 创建时间
    updated_at TIMESTAMP DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT '最后更新时间',
    -- 最后更新时间
    FOREIGN KEY (order_id) REFERENCES purchase_orders(order_id) -- 外键，关联采购订单表
) COMMENT = '采购入库表';

INSERT INTO
    purchase_stock (
        order_id,
        batch_number,
        inspection_status,
        loss_amount
    )
VALUES
    (1, 'BATCH001', 'passed', 0.00),
    (2, 'BATCH002', 'pending', 0.00);

-- 采购对账表
CREATE TABLE purchase_settlements (
    settlement_id INT AUTO_INCREMENT PRIMARY KEY COMMENT '对账ID，主键',
    -- 对账ID
    order_id INT NOT NULL COMMENT '采购订单ID',
    -- 采购订单ID
    settlement_amount DECIMAL(15, 2) NOT NULL COMMENT '结算金额',
    -- 结算金额
    payment_status ENUM('paid', 'unpaid') DEFAULT 'unpaid' COMMENT '付款状态',
    -- 付款状态
    payment_date DATE COMMENT '付款日期',
    -- 付款日期
    created_at TIMESTAMP DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
    -- 创建时间
    updated_at TIMESTAMP DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT '最后更新时间',
    -- 最后更新时间
    FOREIGN KEY (order_id) REFERENCES purchase_orders(order_id) -- 外键，关联采购订单表
) COMMENT = '采购对账表';

INSERT INTO
    purchase_settlements (
        order_id,
        settlement_amount,
        payment_status,
        payment_date
    )
VALUES
    (1, 5000.00, 'paid', '2023-10-05'),
    (2, 3000.00, 'unpaid', NULL);

-- 采购订单商品表
CREATE TABLE purchase_order_items (
    item_id INT AUTO_INCREMENT PRIMARY KEY COMMENT '订单商品ID，主键',
    -- 订单商品ID
    order_id INT NOT NULL COMMENT '采购订单ID',
    -- 采购订单ID
    product_name VARCHAR(100) NOT NULL COMMENT '商品名称',
    -- 商品名称
    quantity INT NOT NULL COMMENT '商品数量',
    -- 商品数量
    unit_price DECIMAL(15, 2) NOT NULL COMMENT '商品单价',
    -- 商品单价
    total_price DECIMAL(15, 2) NOT NULL COMMENT '商品总价',
    -- 商品总价
    created_at TIMESTAMP DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
    -- 创建时间
    updated_at TIMESTAMP DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT '最后更新时间',
    -- 最后更新时间
    FOREIGN KEY (order_id) REFERENCES purchase_orders(order_id) -- 外键，关联采购订单表
) COMMENT = '采购订单商品表';

INSERT INTO
    purchase_order_items (
        order_id,
        product_name,
        quantity,
        unit_price,
        total_price
    )
VALUES
    (1, '商品A', 100, 50.00, 5000.00),
    (2, '商品B', 50, 60.00, 3000.00);

-- 采购入库商品表
CREATE TABLE purchase_stock_items (
    stock_item_id INT AUTO_INCREMENT PRIMARY KEY COMMENT '入库商品ID，主键',
    -- 入库商品ID
    stock_id INT NOT NULL COMMENT '入库ID',
    -- 入库ID
    product_name VARCHAR(100) NOT NULL COMMENT '商品名称',
    -- 商品名称
    quantity INT NOT NULL COMMENT '商品数量',
    -- 商品数量
    unit_price DECIMAL(15, 2) NOT NULL COMMENT '商品单价',
    -- 商品单价
    total_price DECIMAL(15, 2) NOT NULL COMMENT '商品总价',
    -- 商品总价
    created_at TIMESTAMP DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
    -- 创建时间
    updated_at TIMESTAMP DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT '最后更新时间',
    -- 最后更新时间
    FOREIGN KEY (stock_id) REFERENCES purchase_stock(stock_id) -- 外键，关联采购入库表
) COMMENT = '采购入库商品表';

INSERT INTO
    purchase_stock_items (
        stock_id,
        product_name,
        quantity,
        unit_price,
        total_price
    )
VALUES
    (1, '商品A', 100, 50.00, 5000.00),
    (2, '商品B', 50, 60.00, 3000.00);

-- 商品表
CREATE TABLE products (
    product_id INT AUTO_INCREMENT PRIMARY KEY COMMENT '商品ID，主键',
    -- 商品ID
    product_name VARCHAR(100) NOT NULL COMMENT '商品名称',
    -- 商品名称
    barcode VARCHAR(50) NOT NULL COMMENT '条码',
    -- 条码
    unit VARCHAR(20) NOT NULL COMMENT '单位',
    -- 单位
    unit_price DECIMAL(15, 2) NOT NULL COMMENT '单价',
    -- 单价
    brand VARCHAR(50) COMMENT '品牌',
    -- 品牌
    manufacturer VARCHAR(100) COMMENT '生产商',
    -- 生产商
    sku_code VARCHAR(50) COMMENT 'SKU编码',
    -- SKU编码
    image_url VARCHAR(255) COMMENT '商品图片URL',
    -- 商品图片URL
    created_at TIMESTAMP DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
    -- 创建时间
    updated_at TIMESTAMP DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT '最后更新时间',
    -- 最后更新时间
    UNIQUE (barcode) -- 条码唯一
) COMMENT = '商品表' CHARACTER SET = utf8mb4 COLLATE = utf8mb4_unicode_ci;

INSERT INTO
    products (
        product_name,
        barcode,
        unit,
        unit_price,
        brand,
        manufacturer,
        sku_code
    )
VALUES
    (
        '商品A',
        '1234567890123',
        '个',
        50.00,
        '品牌X',
        '生产商X',
        'SKU001'
    ),
    (
        '商品B',
        '1234567890124',
        '个',
        60.00,
        '品牌Y',
        '生产商Y',
        'SKU002'
    );

-- 商品批次表
CREATE TABLE product_batches (
    batch_id INT AUTO_INCREMENT PRIMARY KEY COMMENT '批次ID，主键',
    -- 批次ID
    product_id INT NOT NULL COMMENT '商品ID',
    -- 商品ID
    batch_number VARCHAR(50) NOT NULL COMMENT '批次号',
    -- 批次号
    production_date DATE NOT NULL COMMENT '生产日期',
    -- 生产日期
    expiration_date DATE NOT NULL COMMENT '到期日期',
    -- 到期日期
    created_at TIMESTAMP DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
    -- 创建时间
    updated_at TIMESTAMP DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT '最后更新时间',
    -- 最后更新时间
    FOREIGN KEY (product_id) REFERENCES products(product_id) -- 外键，关联商品表
) COMMENT = '商品批次表' CHARACTER SET = utf8mb4 COLLATE = utf8mb4_unicode_ci;

ALTER TABLE
    product_batches
ADD
    COLUMN batch_remark text COMMENT '批次备注';

INSERT INTO
    product_batches (
        product_id,
        batch_number,
        production_date,
        expiration_date
    )
VALUES
    (1, '批次001', '2023-01-01', '2024-01-01'),
    (2, '批次002', '2023-02-01', '2024-02-01');

-- 仓库表
CREATE TABLE warehouses (
    warehouse_id INT AUTO_INCREMENT PRIMARY KEY COMMENT '仓库ID，主键',
    -- 仓库ID
    warehouse_name VARCHAR(100) NOT NULL COMMENT '仓库名称',
    -- 仓库名称
    location VARCHAR(255) COMMENT '仓库地址',
    -- 仓库地址
    type ENUM('headquarters', 'branch', 'store') NOT NULL COMMENT '仓库类型（总部、分仓、门店）',
    -- 仓库类型
    created_at TIMESTAMP DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
    -- 创建时间
    updated_at TIMESTAMP DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT '最后更新时间' -- 最后更新时间
) COMMENT = '仓库表' CHARACTER SET = utf8mb4 COLLATE = utf8mb4_unicode_ci;

INSERT INTO
    warehouses (warehouse_name, location, type)
VALUES
    ('总部仓库', '北京', 'headquarters'),
    ('分仓A', '上海', 'branch'),
    ('门店A', '广州', 'store');

-- 库存表
CREATE TABLE inventory (
    inventory_id INT AUTO_INCREMENT PRIMARY KEY COMMENT '库存ID，主键',
    -- 库存ID
    warehouse_id INT NOT NULL COMMENT '仓库ID',
    -- 仓库ID
    product_id INT NOT NULL COMMENT '商品ID',
    -- 商品ID
    batch_id INT NOT NULL COMMENT '批次ID',
    -- 批次ID
    quantity INT NOT NULL COMMENT '库存数量',
    -- 库存数量
    min_stock_level INT NOT NULL COMMENT '最低库存量',
    -- 最低库存量
    created_at TIMESTAMP DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
    -- 创建时间
    updated_at TIMESTAMP DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT '最后更新时间',
    -- 最后更新时间
    FOREIGN KEY (warehouse_id) REFERENCES warehouses(warehouse_id),
    -- 外键，关联仓库表
    FOREIGN KEY (product_id) REFERENCES products(product_id),
    -- 外键，关联商品表
    FOREIGN KEY (batch_id) REFERENCES product_batches(batch_id) -- 外键，关联商品批次表
) COMMENT = '库存表' CHARACTER SET = utf8mb4 COLLATE = utf8mb4_unicode_ci;

INSERT INTO
    inventory (
        warehouse_id,
        product_id,
        batch_id,
        quantity,
        min_stock_level
    )
VALUES
    (1, 1, 1, 100, 10),
    (2, 2, 2, 200, 20);

-- 库存调拨表
CREATE TABLE inventory_transfers (
    transfer_id INT AUTO_INCREMENT PRIMARY KEY COMMENT '调拨ID，主键',
    -- 调拨ID
    from_warehouse_id INT NOT NULL COMMENT '调出仓库ID',
    -- 调出仓库ID
    to_warehouse_id INT NOT NULL COMMENT '调入仓库ID',
    -- 调入仓库ID
    product_id INT NOT NULL COMMENT '商品ID',
    -- 商品ID
    batch_id INT NOT NULL COMMENT '批次ID',
    -- 批次ID
    quantity INT NOT NULL COMMENT '调拨数量',
    -- 调拨数量
    transfer_date DATE NOT NULL COMMENT '调拨日期',
    -- 调拨日期
    status ENUM('pending', 'completed', 'cancelled') DEFAULT 'pending' COMMENT '调拨状态',
    -- 调拨状态
    created_at TIMESTAMP DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
    -- 创建时间
    updated_at TIMESTAMP DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT '最后更新时间',
    -- 最后更新时间
    FOREIGN KEY (from_warehouse_id) REFERENCES warehouses(warehouse_id),
    -- 外键，关联调出仓库
    FOREIGN KEY (to_warehouse_id) REFERENCES warehouses(warehouse_id),
    -- 外键，关联调入仓库
    FOREIGN KEY (product_id) REFERENCES products(product_id),
    -- 外键，关联商品表
    FOREIGN KEY (batch_id) REFERENCES product_batches(batch_id) -- 外键，关联商品批次表
) COMMENT = '库存调拨表' CHARACTER SET = utf8mb4 COLLATE = utf8mb4_unicode_ci;

INSERT INTO
    inventory_transfers (
        from_warehouse_id,
        to_warehouse_id,
        product_id,
        batch_id,
        quantity,
        transfer_date
    )
VALUES
    (1, 2, 1, 1, 50, '2023-10-10');

-- 盘点表
CREATE TABLE inventory_checks (
    check_id INT AUTO_INCREMENT PRIMARY KEY COMMENT '盘点ID，主键',
    -- 盘点ID
    warehouse_id INT NOT NULL COMMENT '仓库ID',
    -- 仓库ID
    product_id INT NOT NULL COMMENT '商品ID',
    -- 商品ID
    batch_id INT NOT NULL COMMENT '批次ID',
    -- 批次ID
    expected_quantity INT NOT NULL COMMENT '预期数量',
    -- 预期数量
    actual_quantity INT NOT NULL COMMENT '实际数量',
    -- 实际数量
    difference INT NOT NULL COMMENT '差异数量',
    -- 差异数量
    check_date DATE NOT NULL COMMENT '盘点日期',
    -- 盘点日期
    status ENUM('pending', 'completed') DEFAULT 'pending' COMMENT '盘点状态',
    -- 盘点状态
    created_at TIMESTAMP DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
    -- 创建时间
    updated_at TIMESTAMP DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT '最后更新时间',
    -- 最后更新时间
    FOREIGN KEY (warehouse_id) REFERENCES warehouses(warehouse_id),
    -- 外键，关联仓库表
    FOREIGN KEY (product_id) REFERENCES products(product_id),
    -- 外键，关联商品表
    FOREIGN KEY (batch_id) REFERENCES product_batches(batch_id) -- 外键，关联商品批次表
) COMMENT = '盘点表' CHARACTER SET = utf8mb4 COLLATE = utf8mb4_unicode_ci;

INSERT INTO
    inventory_checks (
        warehouse_id,
        product_id,
        batch_id,
        expected_quantity,
        actual_quantity,
        difference,
        check_date
    )
VALUES
    (1, 1, 1, 100, 95, -5, '2023-10-10');

-- 客户表
CREATE TABLE customers (
    customer_id INT AUTO_INCREMENT PRIMARY KEY COMMENT '客户ID，主键',
    customer_name VARCHAR(100) NOT NULL COMMENT '客户名称',
    contact_person VARCHAR(50) COMMENT '联系人',
    phone VARCHAR(20) COMMENT '联系电话',
    email VARCHAR(100) COMMENT '电子邮箱',
    address VARCHAR(200) COMMENT '地址',
    customer_type ENUM('retail', 'wholesale') NOT NULL DEFAULT 'retail' COMMENT '客户类型：零售/批发',
    credit_limit DECIMAL(12, 2) DEFAULT 0 COMMENT '信用额度',
    account_period INT DEFAULT 0 COMMENT '账期（天）',
    created_at TIMESTAMP DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
    updated_at TIMESTAMP DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT '最后更新时间'
) COMMENT = '客户表' CHARACTER SET = utf8mb4 COLLATE = utf8mb4_unicode_ci;

-- 初始示例数据
INSERT INTO
    customers (
        customer_name,
        contact_person,
        phone,
        email,
        address,
        customer_type,
        credit_limit,
        account_period
    )
VALUES
    (
        '零售客户A',
        '张三',
        '13800138001',
        'zhangsan@example.com',
        '广州市天河区天河路123号',
        'retail',
        0,
        0
    ),
    (
        '批发商B',
        '李四',
        '13900139002',
        'lisi@example.com',
        '广州市白云区白云路456号',
        'wholesale',
        50000.00,
        30
    ),
    (
        '连锁超市C',
        '王五',
        '13700137003',
        'wangwu@example.com',
        '广州市越秀区越秀路789号',
        'wholesale',
        100000.00,
        45
    );

-- 销售订单表
CREATE TABLE sales_orders (
    order_id INT AUTO_INCREMENT PRIMARY KEY COMMENT '订单ID，主键',
    order_number VARCHAR(20) NOT NULL COMMENT '订单编号',
    customer_id INT NOT NULL COMMENT '客户ID',
    order_date DATE NOT NULL COMMENT '订单日期',
    delivery_date DATE COMMENT '预计发货日期',
    order_status ENUM(
        'pending',
        'approved',
        'shipping',
        'completed',
        'cancelled'
    ) NOT NULL DEFAULT 'pending' COMMENT '订单状态',
    payment_status ENUM('unpaid', 'partial', 'paid') NOT NULL DEFAULT 'unpaid' COMMENT '付款状态',
    total_amount DECIMAL(12, 2) NOT NULL DEFAULT 0 COMMENT '订单总金额',
    paid_amount DECIMAL(12, 2) NOT NULL DEFAULT 0 COMMENT '已付金额',
    discount DECIMAL(12, 2) NOT NULL DEFAULT 0 COMMENT '折扣金额',
    remark TEXT COMMENT '备注',
    created_by INT COMMENT '创建人ID',
    approved_by INT COMMENT '审核人ID',
    approved_at TIMESTAMP NULL COMMENT '审核时间',
    created_at TIMESTAMP DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
    updated_at TIMESTAMP DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT '最后更新时间',
    FOREIGN KEY (customer_id) REFERENCES customers(customer_id),
    FOREIGN KEY (created_by) REFERENCES users(user_id),
    FOREIGN KEY (approved_by) REFERENCES users(user_id)
) COMMENT = '销售订单表' CHARACTER SET = utf8mb4 COLLATE = utf8mb4_unicode_ci;

ALTER TABLE
    sales_orders
ADD
    COLUMN receivable_id INT NULL COMMENT '关联应收账款ID'
AFTER
    remark;

-- 销售订单明细表
CREATE TABLE sales_order_items (
    item_id INT AUTO_INCREMENT PRIMARY KEY COMMENT '明细ID，主键',
    order_id INT NOT NULL COMMENT '订单ID',
    product_id INT NOT NULL COMMENT '商品ID',
    batch_id INT COMMENT '批次ID',
    quantity INT NOT NULL COMMENT '数量',
    unit_price DECIMAL(10, 2) NOT NULL COMMENT '单价',
    discount_rate DECIMAL(5, 2) DEFAULT 0 COMMENT '折扣率',
    item_amount DECIMAL(12, 2) NOT NULL COMMENT '项目金额',
    remark TEXT COMMENT '备注',
    created_at TIMESTAMP DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
    updated_at TIMESTAMP DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT '最后更新时间',
    FOREIGN KEY (order_id) REFERENCES sales_orders(order_id),
    FOREIGN KEY (product_id) REFERENCES products(product_id),
    FOREIGN KEY (batch_id) REFERENCES product_batches(batch_id)
) COMMENT = '销售订单明细表' CHARACTER SET = utf8mb4 COLLATE = utf8mb4_unicode_ci;

-- 销售开单（发票）表
CREATE TABLE sales_invoices (
    invoice_id INT AUTO_INCREMENT PRIMARY KEY COMMENT '发票ID，主键',
    invoice_number VARCHAR(20) NOT NULL COMMENT '发票编号',
    order_id INT COMMENT '关联订单ID',
    customer_id INT NOT NULL COMMENT '客户ID',
    invoice_date DATE NOT NULL COMMENT '开票日期',
    invoice_type ENUM('retail', 'wholesale') NOT NULL DEFAULT 'retail' COMMENT '发票类型：零售/批发',
    invoice_status ENUM('draft', 'issued', 'cancelled') NOT NULL DEFAULT 'draft' COMMENT '发票状态',
    payment_status ENUM('unpaid', 'partial', 'paid') NOT NULL DEFAULT 'unpaid' COMMENT '付款状态',
    total_amount DECIMAL(12, 2) NOT NULL DEFAULT 0 COMMENT '发票总金额',
    paid_amount DECIMAL(12, 2) NOT NULL DEFAULT 0 COMMENT '已付金额',
    due_date DATE COMMENT '付款截止日期',
    remark TEXT COMMENT '备注',
    created_by INT COMMENT '创建人ID',
    created_at TIMESTAMP DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
    updated_at TIMESTAMP DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT '最后更新时间',
    FOREIGN KEY (order_id) REFERENCES sales_orders(order_id),
    FOREIGN KEY (customer_id) REFERENCES customers(customer_id),
    FOREIGN KEY (created_by) REFERENCES users(user_id)
) COMMENT = '销售开单表' CHARACTER SET = utf8mb4 COLLATE = utf8mb4_unicode_ci;

ALTER TABLE
    sales_invoices
ADD
    COLUMN receivable_id INT NULL COMMENT '关联应收账款ID'
AFTER
    remark;

-- 销售发票明细表
CREATE TABLE sales_invoice_items (
    item_id INT AUTO_INCREMENT PRIMARY KEY COMMENT '明细ID，主键',
    invoice_id INT NOT NULL COMMENT '发票ID',
    product_id INT NOT NULL COMMENT '商品ID',
    batch_id INT COMMENT '批次ID',
    quantity INT NOT NULL COMMENT '数量',
    unit_price DECIMAL(10, 2) NOT NULL COMMENT '单价',
    discount_rate DECIMAL(5, 2) DEFAULT 0 COMMENT '折扣率',
    item_amount DECIMAL(12, 2) NOT NULL COMMENT '项目金额',
    remark TEXT COMMENT '备注',
    created_at TIMESTAMP DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
    updated_at TIMESTAMP DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT '最后更新时间',
    FOREIGN KEY (invoice_id) REFERENCES sales_invoices(invoice_id),
    FOREIGN KEY (product_id) REFERENCES products(product_id),
    FOREIGN KEY (batch_id) REFERENCES product_batches(batch_id)
) COMMENT = '销售发票明细表' CHARACTER SET = utf8mb4 COLLATE = utf8mb4_unicode_ci;

ALTER TABLE
    sales_invoice_items
ADD
    COLUMN warehouse_id INT
AFTER
    product_id,
ADD
    CONSTRAINT fk_warehouse FOREIGN KEY (warehouse_id) REFERENCES warehouses(warehouse_id);

-- 销售出库表
CREATE TABLE sales_deliveries (
    delivery_id INT AUTO_INCREMENT PRIMARY KEY COMMENT '出库ID，主键',
    delivery_number VARCHAR(20) NOT NULL COMMENT '出库单号',
    order_id INT COMMENT '关联订单ID',
    invoice_id INT COMMENT '关联发票ID',
    customer_id INT NOT NULL COMMENT '客户ID',
    warehouse_id INT NOT NULL COMMENT '仓库ID',
    delivery_date DATE NOT NULL COMMENT '出库日期',
    delivery_status ENUM(
        'pending',
        'in_progress',
        'completed',
        'cancelled'
    ) NOT NULL DEFAULT 'pending' COMMENT '出库状态',
    shipping_address VARCHAR(200) COMMENT '配送地址',
    contact_person VARCHAR(50) COMMENT '联系人',
    contact_phone VARCHAR(20) COMMENT '联系电话',
    remark TEXT COMMENT '备注',
    created_by INT COMMENT '创建人ID',
    created_at TIMESTAMP DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
    updated_at TIMESTAMP DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT '最后更新时间',
    FOREIGN KEY (order_id) REFERENCES sales_orders(order_id),
    FOREIGN KEY (invoice_id) REFERENCES sales_invoices(invoice_id),
    FOREIGN KEY (customer_id) REFERENCES customers(customer_id),
    FOREIGN KEY (warehouse_id) REFERENCES warehouses(warehouse_id),
    FOREIGN KEY (created_by) REFERENCES users(user_id)
) COMMENT = '销售出库表' CHARACTER SET = utf8mb4 COLLATE = utf8mb4_unicode_ci;

-- 销售出库明细表
CREATE TABLE sales_delivery_items (
    item_id INT AUTO_INCREMENT PRIMARY KEY COMMENT '明细ID，主键',
    delivery_id INT NOT NULL COMMENT '出库ID',
    product_id INT NOT NULL COMMENT '商品ID',
    batch_id INT NOT NULL COMMENT '批次ID',
    quantity INT NOT NULL COMMENT '数量',
    unit_price DECIMAL(10, 2) NOT NULL COMMENT '单价',
    item_amount DECIMAL(12, 2) NOT NULL COMMENT '项目金额',
    remark TEXT COMMENT '备注',
    created_at TIMESTAMP DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
    updated_at TIMESTAMP DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT '最后更新时间',
    FOREIGN KEY (delivery_id) REFERENCES sales_deliveries(delivery_id),
    FOREIGN KEY (product_id) REFERENCES products(product_id),
    FOREIGN KEY (batch_id) REFERENCES product_batches(batch_id)
) COMMENT = '销售出库明细表' CHARACTER SET = utf8mb4 COLLATE = utf8mb4_unicode_ci;

-- 销售账款表
CREATE TABLE sales_receivables (
    receivable_id INT AUTO_INCREMENT PRIMARY KEY COMMENT '应收款ID，主键',
    invoice_id INT NOT NULL COMMENT '关联发票ID',
    customer_id INT NOT NULL COMMENT '客户ID',
    amount DECIMAL(12, 2) NOT NULL COMMENT '应收金额',
    due_date DATE NOT NULL COMMENT '到期日',
    payment_status ENUM('unpaid', 'partial', 'paid') NOT NULL DEFAULT 'unpaid' COMMENT '付款状态',
    paid_amount DECIMAL(12, 2) NOT NULL DEFAULT 0 COMMENT '已付金额',
    remaining_amount DECIMAL(12, 2) NOT NULL COMMENT '剩余应收金额',
    remark TEXT COMMENT '备注',
    created_at TIMESTAMP DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
    updated_at TIMESTAMP DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT '最后更新时间',
    FOREIGN KEY (invoice_id) REFERENCES sales_invoices(invoice_id),
    FOREIGN KEY (customer_id) REFERENCES customers(customer_id)
) COMMENT = '销售应收账款表' CHARACTER SET = utf8mb4 COLLATE = utf8mb4_unicode_ci;

-- 销售回款记录表
CREATE TABLE sales_payments (
    payment_id INT AUTO_INCREMENT PRIMARY KEY COMMENT '回款ID，主键',
    payment_number VARCHAR(20) NOT NULL COMMENT '回款单号',
    customer_id INT NOT NULL COMMENT '客户ID',
    payment_date DATE NOT NULL COMMENT '回款日期',
    payment_method ENUM(
        'cash',
        'bank_transfer',
        'alipay',
        'wechat',
        'other'
    ) NOT NULL COMMENT '支付方式',
    amount DECIMAL(12, 2) NOT NULL COMMENT '回款金额',
    remark TEXT COMMENT '备注',
    created_by INT COMMENT '创建人ID',
    created_at TIMESTAMP DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
    updated_at TIMESTAMP DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT '最后更新时间',
    FOREIGN KEY (customer_id) REFERENCES customers(customer_id),
    FOREIGN KEY (created_by) REFERENCES users(user_id)
) COMMENT = '销售回款记录表' CHARACTER SET = utf8mb4 COLLATE = utf8mb4_unicode_ci;

-- 销售回款明细表（关联应收账款）
CREATE TABLE sales_payment_details (
    detail_id INT AUTO_INCREMENT PRIMARY KEY COMMENT '明细ID，主键',
    payment_id INT NOT NULL COMMENT '回款ID',
    receivable_id INT NOT NULL COMMENT '应收款ID',
    amount DECIMAL(12, 2) NOT NULL COMMENT '分配金额',
    created_at TIMESTAMP DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
    updated_at TIMESTAMP DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT '最后更新时间',
    FOREIGN KEY (payment_id) REFERENCES sales_payments(payment_id),
    FOREIGN KEY (receivable_id) REFERENCES sales_receivables(receivable_id)
) COMMENT = '销售回款明细表' CHARACTER SET = utf8mb4 COLLATE = utf8mb4_unicode_ci;

-- 初始化一些销售数据
-- 添加销售订单
INSERT INTO
    sales_orders (
        order_number,
        customer_id,
        order_date,
        delivery_date,
        order_status,
        payment_status,
        total_amount,
        paid_amount,
        created_by
    )
VALUES
    (
        'SO20230001',
        2,
        '2023-07-01',
        '2023-07-10',
        'completed',
        'paid',
        5000.00,
        5000.00,
        1
    ),
    (
        'SO20230002',
        3,
        '2023-07-15',
        '2023-07-25',
        'approved',
        'partial',
        8000.00,
        4000.00,
        1
    );

-- 添加销售订单明细
INSERT INTO
    sales_order_items (
        order_id,
        product_id,
        batch_id,
        quantity,
        unit_price,
        discount_rate,
        item_amount
    )
VALUES
    (1, 1, 1, 50, 50.00, 0.00, 2500.00),
    (1, 2, 2, 50, 50.00, 0.00, 2500.00),
    (2, 1, 1, 100, 50.00, 0.00, 5000.00),
    (2, 2, 2, 50, 60.00, 0.00, 3000.00);

-- 添加销售开单
INSERT INTO
    sales_invoices (
        invoice_number,
        order_id,
        customer_id,
        invoice_date,
        invoice_type,
        invoice_status,
        payment_status,
        total_amount,
        paid_amount,
        due_date,
        created_by
    )
VALUES
    (
        'INV20230001',
        1,
        2,
        '2023-07-05',
        'wholesale',
        'issued',
        'paid',
        5000.00,
        5000.00,
        '2023-08-05',
        1
    ),
    (
        'INV20230002',
        2,
        3,
        '2023-07-20',
        'wholesale',
        'issued',
        'partial',
        8000.00,
        4000.00,
        '2023-09-05',
        1
    );

-- 添加销售发票明细
INSERT INTO
    sales_invoice_items (
        invoice_id,
        product_id,
        batch_id,
        quantity,
        unit_price,
        discount_rate,
        item_amount
    )
VALUES
    (1, 1, 1, 50, 50.00, 0.00, 2500.00),
    (1, 2, 2, 50, 50.00, 0.00, 2500.00),
    (2, 1, 1, 100, 50.00, 0.00, 5000.00),
    (2, 2, 2, 50, 60.00, 0.00, 3000.00);

-- 添加销售出库
INSERT INTO
    sales_deliveries (
        delivery_number,
        order_id,
        invoice_id,
        customer_id,
        warehouse_id,
        delivery_date,
        delivery_status,
        created_by
    )
VALUES
    (
        'DO20230001',
        1,
        1,
        2,
        1,
        '2023-07-08',
        'completed',
        1
    ),
    (
        'DO20230002',
        2,
        2,
        3,
        1,
        '2023-07-23',
        'completed',
        1
    );

-- 添加销售出库明细
INSERT INTO
    sales_delivery_items (
        delivery_id,
        product_id,
        batch_id,
        quantity,
        unit_price,
        item_amount
    )
VALUES
    (1, 1, 1, 50, 50.00, 2500.00),
    (1, 2, 2, 50, 50.00, 2500.00),
    (2, 1, 1, 100, 50.00, 5000.00),
    (2, 2, 2, 50, 60.00, 3000.00);

-- 添加销售应收账款
INSERT INTO
    sales_receivables (
        invoice_id,
        customer_id,
        amount,
        due_date,
        payment_status,
        paid_amount,
        remaining_amount
    )
VALUES
    (
        1,
        2,
        5000.00,
        '2023-08-05',
        'paid',
        5000.00,
        0.00
    ),
    (
        2,
        3,
        8000.00,
        '2023-09-05',
        'partial',
        4000.00,
        4000.00
    );

-- 添加销售回款记录
INSERT INTO
    sales_payments (
        payment_number,
        customer_id,
        payment_date,
        payment_method,
        amount,
        created_by
    )
VALUES
    (
        'PAY20230001',
        2,
        '2023-07-20',
        'bank_transfer',
        5000.00,
        1
    ),
    (
        'PAY20230002',
        3,
        '2023-08-05',
        'bank_transfer',
        4000.00,
        1
    );

-- 添加销售回款明细
INSERT INTO
    sales_payment_details (payment_id, receivable_id, amount)
VALUES
    (1, 1, 5000.00),
    (2, 2, 4000.00);

-- 会员等级表
CREATE TABLE member_levels (
    level_id INT AUTO_INCREMENT PRIMARY KEY COMMENT '等级ID，主键',
    level_name VARCHAR(50) NOT NULL COMMENT '等级名称',
    min_points INT NOT NULL DEFAULT 0 COMMENT '最低积分要求',
    discount_rate DECIMAL(5, 2) NOT NULL DEFAULT 1.00 COMMENT '折扣率',
    description TEXT COMMENT '等级描述',
    created_at TIMESTAMP DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
    updated_at TIMESTAMP DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT '最后更新时间'
) COMMENT = '会员等级表' CHARACTER SET = utf8mb4 COLLATE = utf8mb4_unicode_ci;

-- 会员表
CREATE TABLE members (
    member_id INT AUTO_INCREMENT PRIMARY KEY COMMENT '会员ID，主键',
    customer_id INT NOT NULL COMMENT '客户ID',
    member_no VARCHAR(20) NOT NULL COMMENT '会员卡号',
    level_id INT NOT NULL COMMENT '等级ID',
    points INT NOT NULL DEFAULT 0 COMMENT '当前积分',
    total_amount DECIMAL(12, 2) NOT NULL DEFAULT 0 COMMENT '累计消费金额',
    join_date DATE NOT NULL COMMENT '入会日期',
    status ENUM('active', 'inactive') NOT NULL DEFAULT 'active' COMMENT '会员状态',
    remark TEXT COMMENT '备注',
    created_at TIMESTAMP DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
    updated_at TIMESTAMP DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT '最后更新时间',
    FOREIGN KEY (customer_id) REFERENCES customers(customer_id),
    FOREIGN KEY (level_id) REFERENCES member_levels(level_id),
    UNIQUE KEY (member_no),
    UNIQUE KEY (customer_id)
) COMMENT = '会员表' CHARACTER SET = utf8mb4 COLLATE = utf8mb4_unicode_ci;

-- 促销活动表
CREATE TABLE promotion_activities (
    activity_id INT AUTO_INCREMENT PRIMARY KEY COMMENT '活动ID，主键',
    activity_name VARCHAR(100) NOT NULL COMMENT '活动名称',
    activity_type ENUM('discount', 'full_reduction', 'package') NOT NULL COMMENT '活动类型：折扣/满减/套餐',
    start_date DATE NOT NULL COMMENT '开始日期',
    end_date DATE NOT NULL COMMENT '结束日期',
    is_active TINYINT(1) NOT NULL DEFAULT 1 COMMENT '是否激活',
    discount_rate DECIMAL(5, 2) COMMENT '折扣率（折扣类型适用）',
    min_amount DECIMAL(12, 2) COMMENT '最低金额（满减类型适用）',
    reduction_amount DECIMAL(12, 2) COMMENT '减免金额（满减类型适用）',
    description TEXT COMMENT '活动描述',
    created_by INT COMMENT '创建人ID',
    created_at TIMESTAMP DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
    updated_at TIMESTAMP DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT '最后更新时间',
    FOREIGN KEY (created_by) REFERENCES users(user_id)
) COMMENT = '促销活动表' CHARACTER SET = utf8mb4 COLLATE = utf8mb4_unicode_ci;

-- 促销关联商品表
CREATE TABLE promotion_products (
    id INT AUTO_INCREMENT PRIMARY KEY COMMENT 'ID，主键',
    activity_id INT NOT NULL COMMENT '活动ID',
    product_id INT NOT NULL COMMENT '商品ID',
    discount_rate DECIMAL(5, 2) COMMENT '商品特定折扣率',
    created_at TIMESTAMP DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
    FOREIGN KEY (activity_id) REFERENCES promotion_activities(activity_id),
    FOREIGN KEY (product_id) REFERENCES products(product_id),
    UNIQUE KEY (activity_id, product_id)
) COMMENT = '促销关联商品表' CHARACTER SET = utf8mb4 COLLATE = utf8mb4_unicode_ci;

-- 积分商品表
CREATE TABLE point_products (
    product_id INT AUTO_INCREMENT PRIMARY KEY COMMENT '商品ID，主键',
    product_name VARCHAR(100) NOT NULL COMMENT '商品名称',
    product_type ENUM('physical', 'voucher', 'coupon') NOT NULL COMMENT '商品类型：实物/代金券/优惠券',
    points_required INT NOT NULL COMMENT '所需积分',
    stock_quantity INT NOT NULL DEFAULT 0 COMMENT '库存数量',
    is_active TINYINT(1) NOT NULL DEFAULT 1 COMMENT '是否上架',
    description TEXT COMMENT '商品描述',
    end_date DATE COMMENT '兑换截止日期',
    created_by INT NOT NULL COMMENT '创建人ID',
    created_at TIMESTAMP DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
    updated_at TIMESTAMP DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT '最后更新时间',
    FOREIGN KEY (created_by) REFERENCES users(user_id)
) COMMENT = '积分商品表' CHARACTER SET = utf8mb4 COLLATE = utf8mb4_unicode_ci;

-- 会员等级初始数据
INSERT INTO
    member_levels (
        level_name,
        min_points,
        discount_rate,
        description
    )
VALUES
    ('普通会员', 0, 0.98, '新会员初始等级，享受98折优惠'),
    ('银卡会员', 1000, 0.95, '累计积分达1000分，享受95折优惠'),
    ('金卡会员', 5000, 0.90, '累计积分达5000分，享受9折优惠');

-- 促销活动初始数据
INSERT INTO
    promotion_activities (
        activity_name,
        activity_type,
        start_date,
        end_date,
        is_active,
        discount_rate,
        min_amount,
        reduction_amount,
        description,
        created_by
    )
VALUES
    (
        '夏季大促',
        'discount',
        '2023-06-01',
        '2023-08-31',
        1,
        0.8,
        NULL,
        NULL,
        '夏季大型促销活动，全场商品8折',
        1
    ),
    (
        '满500减100',
        'full_reduction',
        '2023-07-01',
        '2023-09-30',
        1,
        NULL,
        500.00,
        100.00,
        '订单满500元减100元',
        1
    );

-- 积分兑换商品初始数据
INSERT INTO
    point_products (
        product_name,
        product_type,
        points_required,
        stock_quantity,
        is_active,
        description,
        end_date,
        created_by
    )
VALUES
    (
        '保温杯',
        'physical',
        1000,
        100,
        1,
        '精美不锈钢保温杯，容量500ml',
        '2023-12-31',
        1
    ),
    (
        '50元代金券',
        'voucher',
        500,
        200,
        1,
        '可抵扣50元消费金额',
        '2023-12-31',
        1
    );

-- 积分交易表
CREATE TABLE point_transactions (
    transaction_id INT AUTO_INCREMENT PRIMARY KEY COMMENT '交易ID，主键',
    member_id INT NOT NULL COMMENT '会员ID',
    transaction_type ENUM(
        'purchase',
        'redemption',
        'adjustment',
        'expiration',
        'signup',
        'promotion'
    ) NOT NULL COMMENT '交易类型',
    points INT NOT NULL COMMENT '积分变动，正数为增加，负数为减少',
    description VARCHAR(255) NOT NULL COMMENT '交易描述',
    transaction_date DATETIME NOT NULL COMMENT '交易时间',
    related_id INT COMMENT '相关联的ID，如兑换ID等',
    created_by INT COMMENT '操作人ID，适用于管理员操作',
    FOREIGN KEY (member_id) REFERENCES members(member_id),
    FOREIGN KEY (created_by) REFERENCES users(user_id)
) COMMENT = '积分交易记录表' CHARACTER SET = utf8mb4 COLLATE = utf8mb4_unicode_ci;

-- 积分兑换表
CREATE TABLE point_redemptions (
    redemption_id INT AUTO_INCREMENT PRIMARY KEY COMMENT '兑换ID，主键',
    member_id INT NOT NULL COMMENT '会员ID',
    product_id INT NOT NULL COMMENT '积分商品ID',
    quantity INT NOT NULL DEFAULT 1 COMMENT '兑换数量',
    points_used INT NOT NULL COMMENT '消耗的积分',
    redemption_date DATETIME NOT NULL COMMENT '兑换时间',
    status ENUM('pending', 'completed', 'cancelled') NOT NULL DEFAULT 'pending' COMMENT '兑换状态',
    notes TEXT COMMENT '备注信息',
    processed_by INT COMMENT '处理人ID',
    processed_date DATETIME COMMENT '处理时间',
    FOREIGN KEY (member_id) REFERENCES members(member_id),
    FOREIGN KEY (product_id) REFERENCES point_products(product_id),
    FOREIGN KEY (processed_by) REFERENCES users(user_id)
) COMMENT = '积分兑换记录表' CHARACTER SET = utf8mb4 COLLATE = utf8mb4_unicode_ci;

-- 报表配置表
CREATE TABLE report_configs (
    config_id INT AUTO_INCREMENT PRIMARY KEY COMMENT '配置ID，主键',
    report_type VARCHAR(50) NOT NULL COMMENT '报表类型：热门商品/库存分析/销售分析/利润分析/财务报表',
    report_name VARCHAR(100) NOT NULL COMMENT '报表名称',
    refresh_cycle VARCHAR(20) DEFAULT 'daily' COMMENT '刷新周期：daily/weekly/monthly',
    is_active TINYINT(1) DEFAULT 1 COMMENT '是否启用',
    config_params TEXT COMMENT '配置参数，JSON格式',
    created_by INT NOT NULL COMMENT '创建人ID',
    created_at DATETIME DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
    updated_at DATETIME DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT '更新时间',
    INDEX (report_type),
    INDEX (is_active),
    FOREIGN KEY (created_by) REFERENCES users(user_id)
) COMMENT = '报表配置表' CHARACTER SET = utf8mb4 COLLATE = utf8mb4_unicode_ci;

-- 报表统计数据表
CREATE TABLE report_statistics (
    stat_id INT AUTO_INCREMENT PRIMARY KEY COMMENT '统计ID，主键',
    report_type VARCHAR(50) NOT NULL COMMENT '报表类型',
    stat_date DATE NOT NULL COMMENT '统计日期',
    period_type VARCHAR(10) NOT NULL COMMENT '统计周期类型：day/week/month/year',
    stat_data LONGTEXT NOT NULL COMMENT '统计数据，JSON格式',
    created_at DATETIME DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
    updated_at DATETIME DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT '更新时间',
    INDEX (report_type),
    INDEX (stat_date),
    INDEX (period_type),
    UNIQUE KEY (report_type, stat_date, period_type)
) COMMENT = '报表统计数据表' CHARACTER SET = utf8mb4 COLLATE = utf8mb4_unicode_ci;

-- 热门商品统计表
CREATE TABLE product_popularity (
    popularity_id INT AUTO_INCREMENT PRIMARY KEY COMMENT '热门商品统计ID，主键',
    product_id INT NOT NULL COMMENT '商品ID',
    stat_date DATE NOT NULL COMMENT '统计日期',
    period_type VARCHAR(10) NOT NULL COMMENT '统计周期类型：day/week/month/year',
    sales_count INT DEFAULT 0 COMMENT '销售数量',
    sales_amount DECIMAL(12, 2) DEFAULT 0.00 COMMENT '销售金额',
    profit DECIMAL(12, 2) DEFAULT 0.00 COMMENT '利润',
    profit_rate DECIMAL(5, 2) DEFAULT 0.00 COMMENT '利润率(%)',
    rank_by_count INT DEFAULT 0 COMMENT '按销量排名',
    rank_by_amount INT DEFAULT 0 COMMENT '按销售额排名',
    rank_by_profit INT DEFAULT 0 COMMENT '按利润排名',
    created_at DATETIME DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
    updated_at DATETIME DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT '更新时间',
    INDEX (product_id),
    INDEX (stat_date),
    INDEX (period_type),
    INDEX (rank_by_count),
    INDEX (rank_by_amount),
    INDEX (rank_by_profit),
    UNIQUE KEY (product_id, stat_date, period_type),
    FOREIGN KEY (product_id) REFERENCES products(product_id)
) COMMENT = '热门商品统计表' CHARACTER SET = utf8mb4 COLLATE = utf8mb4_unicode_ci;

-- 库存分析表
CREATE TABLE inventory_analysis (
    analysis_id INT AUTO_INCREMENT PRIMARY KEY COMMENT '分析ID，主键',
    product_id INT NOT NULL COMMENT '商品ID',
    warehouse_id INT NOT NULL COMMENT '仓库ID',
    stat_date DATE NOT NULL COMMENT '统计日期',
    period_type VARCHAR(10) NOT NULL COMMENT '统计周期类型：day/week/month/year',
    beginning_inventory INT DEFAULT 0 COMMENT '期初库存',
    ending_inventory INT DEFAULT 0 COMMENT '期末库存',
    sales_quantity INT DEFAULT 0 COMMENT '销售数量',
    turnover_rate DECIMAL(5, 2) DEFAULT 0.00 COMMENT '周转率',
    days_of_inventory INT DEFAULT 0 COMMENT '库存天数',
    stockout_times INT DEFAULT 0 COMMENT '缺货次数',
    slow_moving_days INT DEFAULT 0 COMMENT '呆滞天数',
    is_alert TINYINT(1) DEFAULT 0 COMMENT '是否预警',
    alert_type VARCHAR(20) DEFAULT NULL COMMENT '预警类型：缺货/呆滞/过量',
    created_at DATETIME DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
    updated_at DATETIME DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT '更新时间',
    INDEX (product_id),
    INDEX (warehouse_id),
    INDEX (stat_date),
    INDEX (period_type),
    INDEX (is_alert),
    INDEX (alert_type),
    UNIQUE KEY (product_id, warehouse_id, stat_date, period_type),
    FOREIGN KEY (product_id) REFERENCES products(product_id),
    FOREIGN KEY (warehouse_id) REFERENCES warehouses(warehouse_id)
) COMMENT = '库存分析表' CHARACTER SET = utf8mb4 COLLATE = utf8mb4_unicode_ci;

-- 销售分析表
CREATE TABLE sales_analysis (
    analysis_id INT AUTO_INCREMENT PRIMARY KEY COMMENT '分析ID，主键',
    stat_date DATE NOT NULL COMMENT '统计日期',
    period_type VARCHAR(10) NOT NULL COMMENT '统计周期类型：day/week/month/year',
    dimension_type VARCHAR(20) NOT NULL COMMENT '统计维度：customer/product/region/time',
    dimension_value VARCHAR(50) NOT NULL COMMENT '维度值',
    order_count INT DEFAULT 0 COMMENT '订单数量',
    sales_count INT DEFAULT 0 COMMENT '销售数量',
    sales_amount DECIMAL(12, 2) DEFAULT 0.00 COMMENT '销售金额',
    profit DECIMAL(12, 2) DEFAULT 0.00 COMMENT '利润',
    return_count INT DEFAULT 0 COMMENT '退货数量',
    return_amount DECIMAL(12, 2) DEFAULT 0.00 COMMENT '退货金额',
    rank_num INT DEFAULT 0 COMMENT '排名',
    created_at DATETIME DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
    updated_at DATETIME DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT '更新时间',
    INDEX (stat_date),
    INDEX (period_type),
    INDEX (dimension_type),
    INDEX (dimension_value),
    INDEX (rank_num),
    UNIQUE KEY (
        stat_date,
        period_type,
        dimension_type,
        dimension_value
    )
) COMMENT = '销售分析表' CHARACTER SET = utf8mb4 COLLATE = utf8mb4_unicode_ci;

-- 财务报表表
CREATE TABLE financial_reports (
    report_id INT AUTO_INCREMENT PRIMARY KEY COMMENT '报表ID，主键',
    report_date DATE NOT NULL COMMENT '报表日期',
    period_type VARCHAR(10) NOT NULL COMMENT '统计周期类型：day/month/year',
    total_sales DECIMAL(12, 2) DEFAULT 0.00 COMMENT '总销售额',
    total_cost DECIMAL(12, 2) DEFAULT 0.00 COMMENT '总成本',
    gross_profit DECIMAL(12, 2) DEFAULT 0.00 COMMENT '毛利',
    gross_profit_rate DECIMAL(5, 2) DEFAULT 0.00 COMMENT '毛利率(%)',
    operating_expenses DECIMAL(12, 2) DEFAULT 0.00 COMMENT '运营费用',
    net_profit DECIMAL(12, 2) DEFAULT 0.00 COMMENT '净利润',
    net_profit_rate DECIMAL(5, 2) DEFAULT 0.00 COMMENT '净利率(%)',
    receivables DECIMAL(12, 2) DEFAULT 0.00 COMMENT '应收账款',
    payables DECIMAL(12, 2) DEFAULT 0.00 COMMENT '应付账款',
    inventory_value DECIMAL(12, 2) DEFAULT 0.00 COMMENT '库存价值',
    cash_flow DECIMAL(12, 2) DEFAULT 0.00 COMMENT '现金流',
    created_at DATETIME DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
    updated_at DATETIME DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT '更新时间',
    INDEX (report_date),
    INDEX (period_type),
    UNIQUE KEY (report_date, period_type)
) COMMENT = '财务报表表' CHARACTER SET = utf8mb4 COLLATE = utf8mb4_unicode_ci;

-- 自定义报表表
CREATE TABLE custom_reports (
    custom_report_id INT AUTO_INCREMENT PRIMARY KEY COMMENT '自定义报表ID，主键',
    report_name VARCHAR(100) NOT NULL COMMENT '报表名称',
    report_type VARCHAR(50) NOT NULL COMMENT '报表类型',
    user_id INT NOT NULL COMMENT '创建用户ID',
    query_config TEXT NOT NULL COMMENT '查询配置，JSON格式',
    display_config TEXT NOT NULL COMMENT '显示配置，JSON格式',
    is_public TINYINT(1) DEFAULT 0 COMMENT '是否公开',
    created_at DATETIME DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
    updated_at DATETIME DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT '更新时间',
    INDEX (user_id),
    INDEX (report_type),
    INDEX (is_public),
    FOREIGN KEY (user_id) REFERENCES users(user_id)
) COMMENT = '自定义报表表' CHARACTER SET = utf8mb4 COLLATE = utf8mb4_unicode_ci;

-- 初始化一些示例报表配置
INSERT INTO
    report_configs (
        report_type,
        report_name,
        refresh_cycle,
        is_active,
        config_params,
        created_by
    )
VALUES
    (
        'hot_products',
        '热门商品排行榜',
        'daily',
        1,
        '{"sort_by":"sales_count","limit":20}',
        1
    ),
    (
        'inventory_analysis',
        '库存周转分析',
        'weekly',
        1,
        '{"alert_threshold":30,"slow_moving_days":60}',
        1
    ),
    (
        'sales_analysis',
        '销售趋势分析',
        'monthly',
        1,
        '{"dimensions":["product","customer"]}',
        1
    ),
    (
        'profit_analysis',
        '利润率分析',
        'monthly',
        1,
        '{"min_profit_rate":0.1}',
        1
    ),
    (
        'financial_report',
        '月度财务报表',
        'monthly',
        1,
        '{"include_tax":true}',
        1
    );

-- 为热门商品分析添加一些示例数据
INSERT INTO
    product_popularity (
        product_id,
        stat_date,
        period_type,
        sales_count,
        sales_amount,
        profit,
        profit_rate,
        rank_by_count,
        rank_by_amount,
        rank_by_profit
    )
VALUES
    (
        1,
        '2023-10-01',
        'month',
        120,
        6000.00,
        1800.00,
        30.00,
        1,
        2,
        2
    ),
    (
        2,
        '2023-10-01',
        'month',
        100,
        6500.00,
        2275.00,
        35.00,
        2,
        1,
        1
    ),
    (
        1,
        '2023-09-01',
        'month',
        100,
        5000.00,
        1500.00,
        30.00,
        1,
        1,
        1
    ),
    (
        2,
        '2023-09-01',
        'month',
        80,
        4800.00,
        1680.00,
        35.00,
        2,
        2,
        2
    );

-- 自定义销售分析表
CREATE TABLE custom_sales_analysis (
    id int(11) NOT NULL AUTO_INCREMENT,
    stat_date date NOT NULL COMMENT '统计日期',
    period_type varchar(20) NOT NULL COMMENT '统计周期类型：day,week,month,year',
    dimension_type varchar(20) NOT NULL COMMENT '维度类型：product,customer,category,etc',
    dimension_id int(11) NOT NULL COMMENT '维度ID',
    dimension_name varchar(100) NOT NULL COMMENT '维度名称',
    order_count int(11) NOT NULL DEFAULT 0 COMMENT '订单数量',
    customer_count int(11) NOT NULL DEFAULT 0 COMMENT '客户数量',
    sales_quantity int(11) NOT NULL DEFAULT 0 COMMENT '销售数量',
    sales_amount decimal(12, 2) NOT NULL DEFAULT 0.00 COMMENT '销售金额',
    avg_order_value decimal(12, 2) NOT NULL DEFAULT 0.00 COMMENT '平均订单金额',
    rank_by_amount int(11) NOT NULL DEFAULT 0 COMMENT '按销售额排名',
    created_at timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP,
    PRIMARY KEY (id),
    UNIQUE KEY uk_custom_sales_analysis (
        stat_date,
        period_type,
        dimension_type,
        dimension_id
    )
) COMMENT = '自定义销售分析统计表' CHARACTER SET = utf8mb4 COLLATE = utf8mb4_unicode_ci;

-- 利润分析表
CREATE TABLE profit_analysis (
    id int(11) NOT NULL AUTO_INCREMENT,
    stat_date date NOT NULL COMMENT '统计日期',
    period_type varchar(20) NOT NULL COMMENT '统计周期类型：day,week,month,year',
    dimension_type varchar(20) NOT NULL COMMENT '维度类型：product,category,etc',
    dimension_id int(11) NOT NULL COMMENT '维度ID',
    dimension_name varchar(100) NOT NULL COMMENT '维度名称',
    sales_amount decimal(12, 2) NOT NULL DEFAULT 0.00 COMMENT '销售金额',
    cost_amount decimal(12, 2) NOT NULL DEFAULT 0.00 COMMENT '成本金额',
    gross_profit decimal(12, 2) NOT NULL DEFAULT 0.00 COMMENT '毛利润',
    profit_rate decimal(5, 2) NOT NULL DEFAULT 0.00 COMMENT '毛利率(%)',
    rank_by_profit int(11) NOT NULL DEFAULT 0 COMMENT '按利润排名',
    created_at timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP,
    PRIMARY KEY (id),
    UNIQUE KEY uk_profit_analysis (
        stat_date,
        period_type,
        dimension_type,
        dimension_id
    )
) COMMENT = '利润分析统计表' CHARACTER SET = utf8mb4 COLLATE = utf8mb4_unicode_ci;

-- 物流配送相关表
-- 物流配送方式表
CREATE TABLE logistics_methods (
    method_id INT AUTO_INCREMENT PRIMARY KEY COMMENT '配送方式ID，主键',
    method_name VARCHAR(50) NOT NULL COMMENT '配送方式名称',
    is_third_party TINYINT(1) NOT NULL DEFAULT 0 COMMENT '是否第三方物流',
    cost_formula VARCHAR(255) COMMENT '计费公式',
    description TEXT COMMENT '描述',
    is_active TINYINT(1) NOT NULL DEFAULT 1 COMMENT '是否启用',
    created_at TIMESTAMP DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
    updated_at TIMESTAMP DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT '更新时间'
) COMMENT = '物流配送方式表' CHARACTER SET = utf8mb4 COLLATE = utf8mb4_unicode_ci;

-- 第三方物流公司表
CREATE TABLE logistics_companies (
    company_id INT AUTO_INCREMENT PRIMARY KEY COMMENT '物流公司ID，主键',
    company_name VARCHAR(100) NOT NULL COMMENT '公司名称',
    contact_person VARCHAR(50) COMMENT '联系人',
    contact_phone VARCHAR(20) COMMENT '联系电话',
    company_address VARCHAR(200) COMMENT '公司地址',
    api_key VARCHAR(100) COMMENT 'API密钥',
    api_url VARCHAR(255) COMMENT 'API地址',
    is_active TINYINT(1) NOT NULL DEFAULT 1 COMMENT '是否启用',
    remark TEXT COMMENT '备注',
    created_at TIMESTAMP DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
    updated_at TIMESTAMP DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT '更新时间'
) COMMENT = '第三方物流公司表' CHARACTER SET = utf8mb4 COLLATE = utf8mb4_unicode_ci;

-- 物流订单表
CREATE TABLE logistics_orders (
    logistics_id INT AUTO_INCREMENT PRIMARY KEY COMMENT '物流订单ID，主键',
    logistics_number VARCHAR(30) NOT NULL UNIQUE COMMENT '物流单号',
    delivery_id INT NOT NULL COMMENT '关联销售出库单ID',
    method_id INT NOT NULL COMMENT '配送方式ID',
    company_id INT COMMENT '物流公司ID',
    tracking_number VARCHAR(50) COMMENT '物流跟踪号',
    customer_id INT NOT NULL COMMENT '客户ID',
    shipping_address VARCHAR(200) NOT NULL COMMENT '配送地址',
    receiver_name VARCHAR(50) NOT NULL COMMENT '收货人姓名',
    receiver_phone VARCHAR(20) NOT NULL COMMENT '收货人电话',
    logistics_status ENUM(
        'pending',
        'processing',
        'shipping',
        'delivered',
        'cancelled',
        'exception'
    ) NOT NULL DEFAULT 'pending' COMMENT '物流状态',
    dispatch_time DATETIME COMMENT '发货时间',
    estimated_delivery_time DATETIME COMMENT '预计送达时间',
    actual_delivery_time DATETIME COMMENT '实际送达时间',
    shipping_cost DECIMAL(10, 2) DEFAULT 0.00 COMMENT '运费',
    weight DECIMAL(10, 2) COMMENT '重量(kg)',
    volume DECIMAL(10, 2) COMMENT '体积(m³)',
    remark TEXT COMMENT '备注',
    created_by INT COMMENT '创建人ID',
    created_at TIMESTAMP DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
    updated_at TIMESTAMP DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT '更新时间',
    FOREIGN KEY (delivery_id) REFERENCES sales_deliveries(delivery_id),
    FOREIGN KEY (method_id) REFERENCES logistics_methods(method_id),
    FOREIGN KEY (company_id) REFERENCES logistics_companies(company_id),
    FOREIGN KEY (customer_id) REFERENCES customers(customer_id),
    FOREIGN KEY (created_by) REFERENCES users(user_id)
) COMMENT = '物流订单表' CHARACTER SET = utf8mb4 COLLATE = utf8mb4_unicode_ci;

-- 物流跟踪记录表
CREATE TABLE logistics_tracking (
    tracking_id INT AUTO_INCREMENT PRIMARY KEY COMMENT '跟踪记录ID，主键',
    logistics_id INT NOT NULL COMMENT '物流订单ID',
    tracking_time DATETIME NOT NULL COMMENT '跟踪时间',
    tracking_location VARCHAR(100) COMMENT '当前位置',
    tracking_status VARCHAR(50) NOT NULL COMMENT '跟踪状态',
    tracking_description TEXT NOT NULL COMMENT '状态描述',
    operator VARCHAR(50) COMMENT '操作人',
    is_exception TINYINT(1) DEFAULT 0 COMMENT '是否异常',
    created_at TIMESTAMP DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
    FOREIGN KEY (logistics_id) REFERENCES logistics_orders(logistics_id)
) COMMENT = '物流跟踪记录表' CHARACTER SET = utf8mb4 COLLATE = utf8mb4_unicode_ci;

-- 配送人员表
CREATE TABLE delivery_personnel (
    personnel_id INT AUTO_INCREMENT PRIMARY KEY COMMENT '配送人员ID，主键',
    user_id INT COMMENT '关联用户ID',
    personnel_name VARCHAR(50) NOT NULL COMMENT '姓名',
    phone VARCHAR(20) NOT NULL COMMENT '联系电话',
    license_number VARCHAR(30) COMMENT '驾照编号',
    vehicle_type VARCHAR(30) COMMENT '车辆类型',
    vehicle_number VARCHAR(20) COMMENT '车牌号',
    is_active TINYINT(1) DEFAULT 1 COMMENT '是否在职',
    max_load DECIMAL(10, 2) COMMENT '最大载重(kg)',
    current_location VARCHAR(100) COMMENT '当前位置',
    last_updated DATETIME COMMENT '位置最后更新时间',
    remark TEXT COMMENT '备注',
    created_at TIMESTAMP DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
    updated_at TIMESTAMP DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT '更新时间',
    FOREIGN KEY (user_id) REFERENCES users(user_id)
) COMMENT = '配送人员表' CHARACTER SET = utf8mb4 COLLATE = utf8mb4_unicode_ci;

-- 配送路线表
CREATE TABLE delivery_routes (
    route_id INT AUTO_INCREMENT PRIMARY KEY COMMENT '路线ID，主键',
    route_name VARCHAR(100) COMMENT '路线名称',
    personnel_id INT COMMENT '配送人员ID',
    planned_date DATE NOT NULL COMMENT '计划配送日期',
    start_time DATETIME COMMENT '开始时间',
    end_time DATETIME COMMENT '结束时间',
    total_distance DECIMAL(10, 2) DEFAULT 0.00 COMMENT '总距离(km)',
    total_time INT DEFAULT 0 COMMENT '预计总时间(分钟)',
    status ENUM(
        'planning',
        'assigned',
        'in_progress',
        'completed',
        'cancelled'
    ) DEFAULT 'planning' COMMENT '路线状态',
    created_by INT NOT NULL COMMENT '创建人ID',
    created_at TIMESTAMP DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
    updated_at TIMESTAMP DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT '更新时间',
    FOREIGN KEY (personnel_id) REFERENCES delivery_personnel(personnel_id),
    FOREIGN KEY (created_by) REFERENCES users(user_id)
) COMMENT = '配送路线表' CHARACTER SET = utf8mb4 COLLATE = utf8mb4_unicode_ci;

-- 配送路线详情表
CREATE TABLE delivery_route_details (
    detail_id INT AUTO_INCREMENT PRIMARY KEY COMMENT '详情ID，主键',
    route_id INT NOT NULL COMMENT '路线ID',
    logistics_id INT NOT NULL COMMENT '物流订单ID',
    stop_order INT NOT NULL COMMENT '停靠顺序',
    estimated_arrival_time DATETIME COMMENT '预计到达时间',
    actual_arrival_time DATETIME COMMENT '实际到达时间',
    departure_time DATETIME COMMENT '离开时间',
    stop_status ENUM('pending', 'arrived', 'completed', 'skipped') DEFAULT 'pending' COMMENT '停靠状态',
    remark TEXT COMMENT '备注',
    created_at TIMESTAMP DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
    updated_at TIMESTAMP DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT '更新时间',
    FOREIGN KEY (route_id) REFERENCES delivery_routes(route_id),
    FOREIGN KEY (logistics_id) REFERENCES logistics_orders(logistics_id)
) COMMENT = '配送路线详情表' CHARACTER SET = utf8mb4 COLLATE = utf8mb4_unicode_ci;

-- 区域配送规则表
CREATE TABLE delivery_area_rules (
    rule_id INT AUTO_INCREMENT PRIMARY KEY COMMENT '规则ID，主键',
    area_name VARCHAR(100) NOT NULL COMMENT '区域名称',
    province VARCHAR(50) NOT NULL COMMENT '省份',
    city VARCHAR(50) NOT NULL COMMENT '城市',
    district VARCHAR(50) COMMENT '区县',
    base_cost DECIMAL(10, 2) NOT NULL DEFAULT 0.00 COMMENT '基础运费',
    distance_cost DECIMAL(10, 2) DEFAULT 0.00 COMMENT '每公里费用',
    weight_cost DECIMAL(10, 2) DEFAULT 0.00 COMMENT '每公斤费用',
    min_delivery_time INT DEFAULT 0 COMMENT '最小配送时间(小时)',
    max_delivery_time INT DEFAULT 0 COMMENT '最大配送时间(小时)',
    is_active TINYINT(1) DEFAULT 1 COMMENT '是否启用',
    created_by INT NOT NULL COMMENT '创建人ID',
    created_at TIMESTAMP DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
    updated_at TIMESTAMP DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT '更新时间',
    FOREIGN KEY (created_by) REFERENCES users(user_id)
) COMMENT = '区域配送规则表' CHARACTER SET = utf8mb4 COLLATE = utf8mb4_unicode_ci;

-- 添加物流配送方式初始数据
INSERT INTO
    logistics_methods (
        method_name,
        is_third_party,
        cost_formula,
        description,
        is_active
    )
VALUES
    (
        '公司自配送',
        0,
        '基础费用 + 距离*每公里费用 + 重量*每公斤费用',
        '使用公司自有物流队伍配送',
        1
    ),
    ('顺丰快递', 1, '按物流公司标准计费', '与顺丰合作的第三方快递', 1),
    ('圆通快递', 1, '按物流公司标准计费', '与圆通合作的第三方快递', 1),
    ('京东物流', 1, '按物流公司标准计费', '与京东物流合作的第三方配送', 1);

-- 添加第三方物流公司初始数据
INSERT INTO
    logistics_companies (
        company_name,
        contact_person,
        contact_phone,
        is_active
    )
VALUES
    ('顺丰速运', '张经理', '13800138001', 1),
    ('圆通速递', '李经理', '13900139002', 1),
    ('京东物流', '王经理', '13700137003', 1);

-- 添加配送人员初始数据
INSERT INTO
    delivery_personnel (
        personnel_name,
        phone,
        vehicle_type,
        vehicle_number,
        is_active,
        max_load
    )
VALUES
    ('刘强', '13600136001', '面包车', '粤A12345', 1, 500),
    ('张伟', '13500135002', '小型货车', '粤B54321', 1, 1000),
    ('王刚', '13400134003', '面包车', '粤A67890', 1, 500);

-- 添加区域配送规则初始数据
INSERT INTO
    delivery_area_rules (
        area_name,
        province,
        city,
        district,
        base_cost,
        distance_cost,
        weight_cost,
        min_delivery_time,
        max_delivery_time,
        is_active,
        created_by
    )
VALUES
    (
        '广州市区',
        '广东省',
        '广州市',
        '天河区',
        20.00,
        2.00,
        1.00,
        2,
        8,
        1,
        1
    ),
    (
        '广州近郊',
        '广东省',
        '广州市',
        '白云区',
        25.00,
        2.50,
        1.50,
        4,
        12,
        1,
        1
    ),
    (
        '深圳市区',
        '广东省',
        '深圳市',
        '福田区',
        25.00,
        2.50,
        1.50,
        24,
        48,
        1,
        1
    );


CREATE TABLE IF NOT EXISTS `custom_bills` (
    `bill_id` int(11) NOT NULL AUTO_INCREMENT,
    `bill_type` enum('income', 'expense') NOT NULL COMMENT '账单类型：收入/支出',
    `description` varchar(255) NOT NULL COMMENT '账单描述',
    `amount` decimal(10, 2) NOT NULL COMMENT '金额',
    `transaction_date` date NOT NULL COMMENT '交易日期',
    `payment_method` varchar(50) NOT NULL COMMENT '支付/收款方式',
    `related_customer_id` int(11) DEFAULT NULL COMMENT '相关客户ID',
    `category` varchar(50) DEFAULT NULL COMMENT '账单分类',
    `remark` text DEFAULT NULL COMMENT '备注',
    `created_by` int(11) NOT NULL COMMENT '创建者ID',
    `created_at` timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
    `updated_at` timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP COMMENT '更新时间',
    PRIMARY KEY (`bill_id`),
    KEY `idx_bill_type` (`bill_type`),
    KEY `idx_transaction_date` (`transaction_date`),
    KEY `idx_related_customer` (`related_customer_id`),
    KEY `idx_created_by` (`created_by`)
) ENGINE = InnoDB DEFAULT CHARSET = utf8mb4 COMMENT = '自定义账单表';
