<?php

/**
 * 通用函数库
 */

/**
 * 安全过滤输入数据
 * @param string $data 需要过滤的数据
 * @return string 过滤后的数据
 */
function sanitize($data)
{
    global $conn;
    $data = trim($data);
    $data = stripslashes($data);
    $data = htmlspecialchars($data);
    if ($conn) {
        $data = $conn->real_escape_string($data);
    }
    return $data;
}

/**
 * 检查用户是否已登录
 * 如果未登录，重定向到登录页面
 */
function check_login()
{
    if (!isset($_SESSION['user_id'])) {
        header('Location: ' . BASE_URL . '/login.php');
        exit;
    }
}

/**
 * 记录操作日志
 * @param int $userId 用户ID
 * @param string $operationType 操作类型
 * @param string $operationDetails 操作详情
 * @return bool 操作是否成功
 */
function log_operation($userId, $operationType, $operationDetails)
{
    global $conn;

    $sql = "INSERT INTO operation_logs (user_id, operation_type, operation_details) VALUES (?, ?, ?)";
    $stmt = $conn->prepare($sql);
    $stmt->bind_param("iss", $userId, $operationType, $operationDetails);
    return $stmt->execute();
}

/**
 * 生成分页链接
 * @param int $total 总记录数
 * @param int $page 当前页码
 * @param int $limit 每页记录数
 * @param string $url 链接URL(不含参数)
 * @return string 分页HTML
 */
function generate_pagination($total, $page, $limit, $url)
{
    $totalPages = ceil($total / $limit);
    $html = '<div class="pagination">';

    // 首页
    if ($page > 1) {
        $html .= '<a href="' . $url . '?page=1" class="pagination-item">首页</a>';
    }

    // 上一页
    if ($page > 1) {
        $html .= '<a href="' . $url . '?page=' . ($page - 1) . '" class="pagination-item">上一页</a>';
    }

    // 页码链接
    $start = max(1, $page - 2);
    $end = min($totalPages, $page + 2);

    for ($i = $start; $i <= $end; $i++) {
        if ($i == $page) {
            $html .= '<span class="pagination-item active">' . $i . '</span>';
        } else {
            $html .= '<a href="' . $url . '?page=' . $i . '" class="pagination-item">' . $i . '</a>';
        }
    }

    // 下一页
    if ($page < $totalPages) {
        $html .= '<a href="' . $url . '?page=' . ($page + 1) . '" class="pagination-item">下一页</a>';
    }

    // 末页
    if ($page < $totalPages) {
        $html .= '<a href="' . $url . '?page=' . $totalPages . '" class="pagination-item">末页</a>';
    }

    $html .= '</div>';
    return $html;
}

/**
 * 创建数据库备份
 * @return array 备份结果 ['success' => bool, 'message' => string, 'backup_id' => int|null]
 */
function create_database_backup()
{
    global $conn;

    $backupName = 'backup_' . date('Y-m-d_H-i-s');
    $backupDir = __DIR__ . '/../backups/';

    // 确保备份目录存在
    if (!is_dir($backupDir)) {
        mkdir($backupDir, 0755, true);
    }

    $backupPath = $backupDir . $backupName . '.sql';

    // 在Windows系统中使用mysqldump命令
    $command = 'mysqldump -h ' . DB_HOST . ' -u ' . DB_USER . ' -p' . DB_PASS . ' ' . DB_NAME . ' > ' . $backupPath;

    exec($command, $output, $returnVar);

    if ($returnVar === 0) {
        // 备份成功，记录到数据库
        $sql = "INSERT INTO data_backups (backup_name, backup_path, status) VALUES (?, ?, 'success')";
        $stmt = $conn->prepare($sql);
        $stmt->bind_param("ss", $backupName, $backupPath);

        if ($stmt->execute()) {
            return [
                'success' => true,
                'message' => '数据库备份成功',
                'backup_id' => $stmt->insert_id
            ];
        } else {
            return [
                'success' => false,
                'message' => '备份记录保存失败: ' . $conn->error,
                'backup_id' => null
            ];
        }
    } else {
        // 备份失败
        $sql = "INSERT INTO data_backups (backup_name, backup_path, status) VALUES (?, ?, 'failed')";
        $stmt = $conn->prepare($sql);
        $stmt->bind_param("ss", $backupName, $backupPath);
        $stmt->execute();

        return [
            'success' => false,
            'message' => '数据库备份失败',
            'backup_id' => null
        ];
    }
}

/**
 * 执行预处理SQL查询并返回结果
 * @param mysqli $conn 数据库连接
 * @param string $sql SQL查询语句
 * @param string $types 参数类型
 * @param array $params 绑定参数数组
 * @return array 包含成功状态、数据和消息的数组
 */
function executeQuery($conn, $sql, $types = '', $params = [])
{
    $result = [
        'success' => false,
        'data' => null,
        'message' => '',
        'insert_id' => null
    ];

    try {
        $stmt = $conn->prepare($sql);

        if ($stmt === false) {
            $result['message'] = "准备SQL语句失败: " . $conn->error;
            return $result;
        }

        if (!empty($params) && !empty($types)) {
            $stmt->bind_param($types, ...$params);
        }

        if (!$stmt->execute()) {
            $result['message'] = "执行查询失败: " . $stmt->error;
            $stmt->close();
            return $result;
        }

        // 如果是SELECT查询，获取结果集
        if (stripos(trim($sql), 'SELECT') === 0) {
            $dbResult = $stmt->get_result();
            if ($dbResult) {
                $result['data'] = [];
                while ($row = $dbResult->fetch_assoc()) {
                    $result['data'][] = $row;
                }
            } else {
                $result['message'] = "获取结果集失败: " . $stmt->error;
                $stmt->close();
                return $result;
            }
        } else {
            // 非SELECT查询，返回受影响的行数
            $result['data'] = $stmt->affected_rows;
            $result['insert_id'] = $stmt->insert_id;
        }

        $result['success'] = true;
        $stmt->close();
    } catch (Exception $e) {
        $result['message'] = "查询执行异常: " . $e->getMessage();
    }

    return $result;
}

/**
 * 获取单条记录
 * @param mysqli $conn 数据库连接
 * @param string $table 表名
 * @param int|string $id ID值
 * @param string $idField ID字段名
 * @return array|null 记录数组或null
 */
function getRecordById($conn, $table, $id, $idField = 'id')
{
    $sql = "SELECT * FROM {$table} WHERE {$idField} = ?";
    $result = executeQuery($conn, $sql, 'i', [$id]);

    if ($result['success'] && is_array($result['data']) && count($result['data']) > 0) {
        return $result['data'][0];
    }

    return null;
}

/**
 * 获取记录列表
 * @param mysqli $conn 数据库连接
 * @param string $table 表名
 * @param array $conditions 查询条件数组 ['字段名' => '值']
 * @param string $orderBy 排序字段
 * @param string $order 排序方向 (ASC|DESC)
 * @param int $limit 限制结果数量
 * @param int $offset 结果偏移量
 * @return array 记录数组
 */
function getRecords($conn, $table, $conditions = [], $orderBy = '', $order = 'ASC', $limit = 0, $offset = 0)
{
    $sql = "SELECT * FROM {$table}";
    $params = [];
    $types = '';

    // 添加WHERE条件
    if (!empty($conditions)) {
        $sql .= " WHERE ";
        $whereClauses = [];

        foreach ($conditions as $field => $value) {
            if ($value === null) {
                $whereClauses[] = "{$field} IS NULL";
            } else {
                $whereClauses[] = "{$field} = ?";
                $params[] = $value;

                // 确定参数类型
                if (is_int($value)) {
                    $types .= 'i';
                } elseif (is_double($value) || is_float($value)) {
                    $types .= 'd';
                } else {
                    $types .= 's';
                }
            }
        }

        $sql .= implode(' AND ', $whereClauses);
    }

    // 添加ORDER BY
    if (!empty($orderBy)) {
        $sql .= " ORDER BY {$orderBy} {$order}";
    }

    // 添加LIMIT和OFFSET
    if ($limit > 0) {
        $sql .= " LIMIT {$limit}";
        if ($offset > 0) {
            $sql .= " OFFSET {$offset}";
        }
    }

    $result = executeQuery($conn, $sql, $types, $params);

    if ($result['success'] && is_array($result['data'])) {
        return $result['data'];
    }

    return [];
}

/**
 * 插入记录
 * @param mysqli $conn 数据库连接
 * @param string $table 表名
 * @param array $data 要插入的数据 ['字段名' => '值']
 * @return array 操作结果
 */
function insertRecord($conn, $table, $data)
{
    $fields = array_keys($data);
    $placeholders = array_fill(0, count($fields), '?');
    $values = array_values($data);
    $types = '';

    foreach ($values as $value) {
        if (is_int($value)) {
            $types .= 'i';
        } elseif (is_double($value) || is_float($value)) {
            $types .= 'd';
        } else {
            $types .= 's';
        }
    }

    $sql = "INSERT INTO {$table} (" . implode(', ', $fields) . ") VALUES (" . implode(', ', $placeholders) . ")";
    return executeQuery($conn, $sql, $types, $values);
}

/**
 * 更新记录
 * @param mysqli $conn 数据库连接
 * @param string $table 表名
 * @param array $data 要更新的数据 ['字段名' => '值']
 * @param int|string $id ID值
 * @param string $idField ID字段名
 * @return array 操作结果
 */
function updateRecord($conn, $table, $data, $id, $idField = 'id')
{
    $fields = array_keys($data);
    $setClause = array_map(function ($field) {
        return "{$field} = ?";
    }, $fields);

    $values = array_values($data);
    $values[] = $id;  // 添加WHERE条件的ID值

    $types = '';
    foreach ($values as $value) {
        if (is_int($value)) {
            $types .= 'i';
        } elseif (is_double($value) || is_float($value)) {
            $types .= 'd';
        } else {
            $types .= 's';
        }
    }

    $sql = "UPDATE {$table} SET " . implode(', ', $setClause) . " WHERE {$idField} = ?";
    return executeQuery($conn, $sql, $types, $values);
}

/**
 * 删除记录
 * @param mysqli $conn 数据库连接
 * @param string $table 表名
 * @param int|string $id ID值
 * @param string $idField ID字段名
 * @return array 操作结果
 */
function deleteRecord($conn, $table, $id, $idField = 'id')
{
    $sql = "DELETE FROM {$table} WHERE {$idField} = ?";
    return executeQuery($conn, $sql, 'i', [$id]);
}

/**
 * 检查记录是否存在
 * @param mysqli $conn 数据库连接
 * @param string $table 表名
 * @param array $conditions 查询条件
 * @return bool 记录是否存在
 */
function recordExists($conn, $table, $conditions)
{
    $sql = "SELECT 1 FROM {$table} WHERE ";
    $whereClauses = [];
    $params = [];
    $types = '';

    foreach ($conditions as $field => $value) {
        if ($value === null) {
            $whereClauses[] = "{$field} IS NULL";
        } else {
            $whereClauses[] = "{$field} = ?";
            $params[] = $value;

            if (is_int($value)) {
                $types .= 'i';
            } elseif (is_double($value) || is_float($value)) {
                $types .= 'd';
            } else {
                $types .= 's';
            }
        }
    }

    $sql .= implode(' AND ', $whereClauses) . " LIMIT 1";
    $result = executeQuery($conn, $sql, $types, $params);

    return $result['success'] && is_array($result['data']) && count($result['data']) > 0;
}

/**
 * 批量更新状态
 * @param mysqli $conn 数据库连接
 * @param string $table 表名
 * @param string $idField ID字段名
 * @param string $statusField 状态字段名
 * @param array $ids 要更新的ID数组
 * @param string $newStatus 新状态值
 * @return array 结果数组 ['success' => int, 'failed' => int]
 */
function batchUpdateStatus($conn, $table, $idField, $statusField, $ids, $newStatus)
{
    $result = ['success' => 0, 'failed' => 0];

    if (empty($ids) || !is_array($ids)) {
        return $result;
    }

    $sql = "UPDATE {$table} SET {$statusField} = ? WHERE {$idField} = ?";
    $stmt = $conn->prepare($sql);

    if ($stmt === false) {
        return $result;
    }

    foreach ($ids as $id) {
        $stmt->bind_param('si', $newStatus, $id);

        if ($stmt->execute()) {
            $result['success']++;
        } else {
            $result['failed']++;
        }
    }

    $stmt->close();
    return $result;
}

/**
 * 仓库类型转换函数 - 将英文类型转换为中文显示
 * @param string $type 仓库类型英文值
 * @return string 对应的中文类型
 */
function getWarehouseTypeChinese($type)
{
    switch ($type) {
        case 'headquarters':
            return '总部';
        case 'branch':
            return '分仓';
        case 'store':
            return '门店';
        default:
            return $type;
    }
}
